@@ -1,6 +1,6 @@
 __authors__ = ['Thorin Tabor', 'Chet Birger']
 __copyright__ = 'Copyright 2015-2016, Broad Institute'
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 __status__ = 'Production'
 
 """ GenePattern Python Client
@@ -19,8 +19,10 @@ from contextlib import closing
 # Imports requiring compatibility between Python 2 and Python 3
 if sys.version_info.major == 2:
     import urllib2
+    import urllib as parse
 elif sys.version_info.major == 3:
     from urllib import request as urllib2
+    import urllib.parse as parse
 
 
 class GPServer(object):
@@ -126,7 +128,7 @@ class GPServer(object):
 
         # names should be a list of names,
         # values should be a list of **lists** of values
-        json_string = json.dumps({'lsid': job_spec.lsid, 'params': job_spec.params})
+        json_string = json.dumps({'lsid': job_spec.lsid, 'params': job_spec.params, 'tags': ['GenePattern Python Client']})
         if sys.version_info.major == 3:  # Handle conversion to bytes for Python 3
             json_string = bytes(json_string, 'utf-8')
         request = urllib2.Request(self.url + '/rest/v1/jobs')
@@ -235,11 +237,11 @@ class GPFile(GPResource):
 
     def read(self):
         """
-        Reads the contents of the GPFile and returns the contents as a string
+        Reads the contents of the GPFile and returns the contents as a string (assumes UTF-8)
         """
         with closing(self.open()) as f:
             data = f.read()
-        return data or None
+        return data.decode("utf-8") or None
 
     def get_url(self):
         """
@@ -247,6 +249,12 @@ class GPFile(GPResource):
         """
         return self.uri
 
+    def get_name(self):
+        """
+        Returns the file name of the output file
+        """
+        return parse.unquote(self.get_url().split('/')[-1])
+
 
 class GPJob(GPResource):
     """
@@ -312,7 +320,6 @@ class GPJob(GPResource):
         self.job_number = int(self.info['jobId'])
         self.status = self.get_status_message()
         self.date_submitted = self.info['dateSubmitted']
-        self.date_completed = self.info['dateCompleted']
         self.log_files = self.info['logFiles']
         self.output_files = self.info['outputFiles']
         self.num_output_files = self.info['numOutputFiles']
@@ -441,6 +448,17 @@ class GPJob(GPResource):
         else:
             return []
 
+    def get_file(self, name):
+        """
+        Returns the output file with the specified name, if no output files
+        match, returns None.
+        """
+        files = self.get_output_files()
+        for f in files:
+            if f.get_name() == name:
+                return f
+        return None
+
     def wait_until_done(self):
         """
         This method will not return until the job is either complete or has
